==> nextcloud-28.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/photos/l10n/sr.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Јавна веза",
    "Photos" : "Слике",
    "On This Day" : "На данашњи дан",
    "Your memories under your control" : "Ваше успомене под Вашом контролом",
    "All media" : "Сви медији",
    "Videos" : "Видео снимци",
    "Albums" : "Албуми",
    "Collaborative albums" : "Заједнички албуми",
    "People" : "Људи",
    "Folders" : "Фасцикле",
    "Favorites" : "Омиљене",
    "On this day" : "На данашњи дан",
    "Shared with you" : "Дељено са Вама",
    "Tags" : "Ознаке",
    "Places" : "Места",
    "Map" : "Мапа",
    "Photos settings" : "Подешавања",
    "Mark selection as favorite" : "Означи изабрано као омиљено",
    "Add selection to favorites" : "Додај изабрано у омиљено",
    "Remove selection from favorites" : "Уклони изабрано из омиљених",
    "Name of the album" : "Назив албума",
    "Location of the album" : "Локација албума",
    "Back" : "Назад",
    "Add collaborators" : "Додај сараднике",
    "Save" : "Сачувај",
    "Create album" : "Креирај албум",
    "Add to Album" : "Додај албум",
    "Add selection to album {albumName}" : "Додај изабрано у албум {albumName}",
    "Shared by" : "Поделио",
    "Create a new album." : "Креирање новог албума.",
    "Create new album" : "Креирај албум",
    "New album" : "Нови албум",
    "_%n item_::_%n photos and videos_" : ["%n ставка","%n фотографије и видео снимка","%n форографија и видео снимака"],
    "Add people or groups who can edit your album" : "Додај људе или групе које могу да уређују ваш албум",
    "Search people or groups" : "Претрага људи и група",
    "No recommendations. Start typing." : "Нема препорука. Започните куцање.",
    "Group" : "Група",
    "Remove {collaboratorLabel} from the collaborators list" : "Уклони {collaboratorLabel} из листе сарадника",
    "Copy the public link" : "Копирај јавни линк",
    "Public link copied!" : "Јавни линк је корипан!",
    "Copy public link" : "Копирај јавни линк",
    "Delete the public link" : "Обриши јавни линк",
    "Create public link share" : "Направи дељење јавном везом",
    "Share via public link" : "Подели путем јавног линка",
    "Failed to fetch collaborators list." : "Није успело добављање листе сарадника.",
    "Failed to update album." : "Није успело ажурирање албума.",
    "This collection does not exist" : "Ова колекција не постоји",
    "An error occurred" : "Догодила се грешка",
    "No picture for this day" : "Нема слика за данашњи дан",
    "Picture taken on this day will show up here." : "Овде ће се појавити слика направљена на данашњи дан.",
    "More photos from this day" : "Још слика за данас",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n недодељена фотографија","%n недодељене фотографије","%n недодељених фотографија"],
    "Favorite" : "Омиљени",
    "Select image {imageName}" : "Изабери слику {imageName}",
    "Favorite image, open the full size \"{name}\" image" : "Омиљена слика, отвори слику „{name}” у пуној величини",
    "Open the full size \"{name}\" image" : "Отвори слику „{name}” у пуној величини",
    "Open the \"{name}\" folder" : "Отвори „{name}” директоријум",
    "Go back" : "Иди назад",
    "Back to {folder}" : "Назад у {folder}",
    "Share this folder" : "Дели ову фасциклу",
    "Dates" : "Датуми",
    "Jump to specific date in list" : "Скок на одређени датум у листи",
    "Jump to {date}" : "Скочи на {date}",
    "Add to {destination}" : "Додај у {destination}",
    "There are no photos or videos yet!" : "Још увек нема фотографија или видео снимака!",
    "_{years} year ago_::_{years} years ago_" : ["пре {years} године","пре {years} године","пре {years} година"],
    "Enable squared photos view" : "Укључи квадратасти приказ слика",
    "Delete source directory" : "Обриши изворни директоријум",
    "All folders" : "Сви фолдери",
    "Choose a Photos source for the timelines" : "Изаберите извор који ће Фотографије употребити за временске линије",
    "Choose a different folder" : "Изаберите неки други фолдер",
    "Select a source folder for your media" : "Изаберите извирни фолдер за своје медије",
    "Home" : "Почетна",
    "Choose default Photos upload and Albums location" : "Изаберите подразумевано место за отпремање Фотографија и албума",
    "Select the default upload location for your media" : "Изаберите подразумевано место отпремања својих медија",
    "View" : "Погледај",
    "Media folder" : "Фолдер медија",
    "Choose the folders from where photos and videos are shown." : "Изаберите фолдере из којих се приказују фотографије и видео снимци.",
    "Upload folder" : "Фолдер отпремања",
    "Choose the folder where photos and albums are uploaded to." : "Изаберите фолдер у који се отпремају фотографије и албуми.",
    "_%n photo_::_%n photos_" : ["%n фотографија","%n фотографије","%n фотографија"],
    "Unselect all" : "Поништи цео избор",
    "Manage collaborators for this album" : "Управљање сарадницима на овом албуму",
    "Open actions menu" : "Отвори мени са акцијама",
    "Edit album details" : "Уреди детаље о албуму",
    "Download all files in album" : "Преузми све фајлове у албуму",
    "Delete album" : "Обриши албум",
    "Download selected files" : "Преузми изабране фајлове",
    "Remove selection from album" : "Уклони избор са албума",
    "This album does not have any photos or videos yet!" : "Овај албум још увек нема ниједну фотографију или видео снимак!",
    "Add photos to this album" : "Додај фотографије у овај албум",
    "Add photos to {albumName}" : "Додај фотографије у {albumName}",
    "Manage collaborators" : "Управљај сарадницима",
    "Save collaborators for this album." : "Сачувај сараднике на овом албуму",
    "Cover photo for album {albumName}" : "Фотографија омота за албум {albumName}",
    "There is no album yet!" : "Још увек нема албума!",
    "This person could not be found" : "Ова особа не може да се пронађе",
    "Rename person" : "Промени име особе",
    "Merge with different person" : "Споји са другом особом",
    "Download selected photos" : "Преузми изабране фотографије",
    "Remove from favorites" : "Уклони из омиљених",
    "Remove person" : "Уклони особу",
    "Name of this person" : "Име ове особе",
    "Save." : "Сачувај.",
    "Merge person" : "Споји особу",
    "Move to different person" : "Премести другој особи",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Премести фотографију другој особи","Премести фотографије другој особи","Премести фотографије другој особи"],
    "_Remove photo from person_::_Remove photos from person_" : ["Уклони фотографију особи","Уклони фотографије особи","Уклони фотографије особи"],
    "This might take some time depending on the size of your photo library." : "У зависности од величине ваше фото библиотеке, ово може да потраје неко време.",
    "Recognized people will show up here" : "Овде ће се појавити препознате особе",
    "This folder does not exist" : "Овај фолдер не постоји",
    "Loading folders …" : "Учитавање фолдера ...",
    "No photos in here" : "Овде нема слика",
    "Taken on {date} at {time}" : "Сликано дана {date} у {time}",
    "This place does not have any photos or videos yet!" : "Ово место још увек нема ниједну фотографију или видео снимак!",
    "Add photos to this place" : "Додај фотографије на ово место",
    "Cover photo for place {placeName}" : "Фотографија омота за место {placeName}",
    "There is no place yet!" : "Још увек нема места!",
    "Cover photo for shared album {albumName}." : "Фотографија омота за дељени албум {albumName}.",
    "Back to tags overview" : "Назад на преглед ознака",
    "No photos with this tag yet" : "Још увек нема фотографија са овом ознаком",
    "No tags yet" : "Још нема ознака",
    "Photos with tags will show up here" : "Слике са ознакама ће се појавити овде",
    "Popular tags" : "Популарне ознаке",
    "The source folder does not exists" : "Изворни фолдер не постоји",
    "Add" : "Додај",
    "Add to album" : "Додај у албум",
    "Delete selection" : "Обриши одабир",
    "No photos or videos in here" : "Овде нема фотографија или видео снимака",
    "Unassigned faces" : "Недодељена лица",
    "_%n photos_::_%n photos_" : ["%n фотографија","%n фотографије","%n фотографија"],
    "Failed to fetch collection." : "Није успело добављање колекције.",
    "Failed to fetch collections list." : "Није успело добављање листе колекција.",
    "Failed to fetch faces list." : "Није успело добављање листе лица.",
    "All your media" : "Сви ваши медији",
    "Album {title}" : "Албум {title}",
    "Shared Albums" : "Дељени албуми",
    "Shared album {title}" : "Дељени албум {title}",
    "Public album {title}" : "Јавни албум {title}",
    "Tagged photos" : "Слике са ознаком",
    "Tagged photo {title}" : "Означена фотографија {title}",
    "{title}'s face" : "лице {title}",
    "{startDate} to {endDate}" : "{startDate} до {endDate}",
    "Details" : "Детаљи",
    "Failed to rename {oldName} to {faceName}." : "Није успела промена имена {oldName} у {faceName}.",
    "Failed to delete {faceName}." : "Није успело брисање {faceName}.",
    "Failed to delete {fileId}." : "Није успело брисање {fileId}.",
    "Failed to delete {fileName}." : "Није успело брисање {fileName}.",
    "Failed to set favorite state for {fileId}." : "Није успело постављање стања омиљено за {fileId}.",
    "Failed to set favorite state for {fileName}." : "Није успело постављање стања омиљено за {fileName}.",
    "Could not load photos folder" : "Не може да се учита фолдер фотографија",
    "Go back to the previous view." : "Повратак на претходни поглед.",
    "Go to the add collaborators view." : "Враћање на поглед додавања сарадника",
    "Create the album." : "Креирање албума.",
    "Back to the new album form." : "Повратак на форму новог албума.",
    "_Share with %n user_::_Share with %n users_" : ["Подели са %n корисником","Подели са %n корисника","Подели са %n корисника"],
    "Search for collaborators" : "Претрага сарадника",
    "Add {collaboratorLabel} to the collaborators list" : "Додај {collaboratorLabel} на листу сарадника",
    "No collaborators available" : "Нема достуоних сарадника",
    "Failed to fetch album." : "Није успело добављање албума.",
    "The file is in the favorites" : "Фајл се налази у омиљенима",
    "Open the \"{name}\" sub-directory" : "Отвори „{name}” поддиректоријум",
    "Default Photos upload and Albums location" : "Подразумевано место за отпремање фотографија и албума",
    "Select the default location for your media" : "Изаберите подразумевано место за своје медије",
    "Invalid location selected" : "Изабрана је неисправна локација",
    "Photos directory" : "Директоријум фотографија",
    "Add photos to the album" : "Додај фотографије у албум",
    "Failed to fetch albums list." : "Није успело добављање листе албума.",
    "Shared albums" : "Дељени албуми",
    "Create a new album" : "Креирај нови албум",
    "Add selection to an album" : "Додај изабрано у албум",
    "Failed to create {albumName}." : "{albumName} није могао да се креира.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Није успела промена имена {currentAlbumName} у {newAlbumName}."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-31.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/photos/l10n/sr.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Јавна веза",
    "Photos" : "Слике",
    "On This Day" : "На данашњи дан",
    "Your memories under your control" : "Ваше успомене под Вашом контролом",
    "All media" : "Сви медији",
    "Videos" : "Видео снимци",
    "Albums" : "Албуми",
    "Collaborative albums" : "Заједнички албуми",
    "People" : "Људи",
    "Folders" : "Фасцикле",
    "Favorites" : "Омиљене",
    "On this day" : "На данашњи дан",
    "Shared with you" : "Дељено са Вама",
    "Tags" : "Ознаке",
    "Places" : "Места",
    "Map" : "Мапа",
    "Photos settings" : "Подешавања",
    "Mark selection as favorite" : "Означи изабрано као омиљено",
    "Add selection to favorites" : "Додај изабрано у омиљено",
    "Remove selection from favorites" : "Уклони изабрано из омиљених",
    "Name of the album" : "Назив албума",
    "Location of the album" : "Локација албума",
    "Back" : "Назад",
    "Add collaborators" : "Додај сараднике",
    "Save" : "Сачувај",
    "Create album" : "Креирај албум",
    "Add to Album" : "Додај албум",
    "Add selection to album {albumName}" : "Додај изабрано у албум {albumName}",
    "Shared by" : "Поделио",
    "Create a new album." : "Креирање новог албума.",
    "Create new album" : "Креирај албум",
    "New album" : "Нови албум",
    "_%n item_::_%n photos and videos_" : ["%n ставка","%n фотографије и видео снимка","%n форографија и видео снимака"],
    "Failed to fetch collaborators list." : "Није успело добављање листе сарадника.",
    "Failed to update album." : "Није успело ажурирање албума.",
    "Add people or groups who can edit your album" : "Додај људе или групе које могу да уређују ваш албум",
    "Search people or groups" : "Претрага људи и група",
    "No recommendations. Start typing." : "Нема препорука. Започните куцање.",
    "Group" : "Група",
    "Remove {collaboratorLabel} from the collaborators list" : "Уклони {collaboratorLabel} из листе сарадника",
    "Copy the public link" : "Копирај јавни линк",
    "Public link copied!" : "Јавни линк је корипан!",
    "Copy public link" : "Копирај јавни линк",
    "Delete the public link" : "Обриши јавни линк",
    "Create public link share" : "Направи дељење јавном везом",
    "Share via public link" : "Подели путем јавног линка",
    "This collection does not exist" : "Ова колекција не постоји",
    "An error occurred" : "Догодила се грешка",
    "No picture for this day" : "Нема слика за данашњи дан",
    "Picture taken on this day will show up here." : "Овде ће се појавити слика направљена на данашњи дан.",
    "More photos from this day" : "Још слика за данас",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n недодељена фотографија","%n недодељене фотографије","%n недодељених фотографија"],
    "Favorite" : "Омиљени",
    "Favorite image, open the full size \"{name}\" image" : "Омиљена слика, отвори слику „{name}” у пуној величини",
    "Open the full size \"{name}\" image" : "Отвори слику „{name}” у пуној величини",
    "Select image {imageName}" : "Изабери слику {imageName}",
    "Open the \"{name}\" folder" : "Отвори „{name}” директоријум",
    "Back to {folder}" : "Назад у {folder}",
    "Go back" : "Иди назад",
    "Share this folder" : "Дели ову фасциклу",
    "Dates" : "Датуми",
    "Jump to specific date in list" : "Скок на одређени датум у листи",
    "Jump to {date}" : "Скочи на {date}",
    "Add to {destination}" : "Додај у {destination}",
    "The destination folder is owned by {owner}" : "{owner} је власник циљног фолдера",
    "There are no photos or videos yet!" : "Још увек нема фотографија или видео снимака!",
    "_{years} year ago_::_{years} years ago_" : ["пре {years} године","пре {years} године","пре {years} година"],
    "Enable squared photos view" : "Укључи квадратасти приказ слика",
    "Delete source directory" : "Обриши изворни директоријум",
    "Pick folder" : "Изаберите фолдер",
    "Select a source folder for your media" : "Изаберите извирни фолдер за своје медије",
    "All folders" : "Сви фолдери",
    "Add a Photos source for the timelines" : "Додајте извор који ће Фотографије употребити за временске линије",
    "Add folder" : "Додај фасциклу",
    "Select the default upload location for your media" : "Изаберите подразумевано место отпремања својих медија",
    "Home" : "Почетна",
    "Choose default Photos upload and Albums location" : "Изаберите подразумевано место за отпремање Фотографија и албума",
    "Choose a different folder" : "Изаберите неки други фолдер",
    "View" : "Погледај",
    "Media folders" : "Фолдери медија",
    "Choose the folders from where photos and videos are shown." : "Изаберите фолдере из којих се приказују фотографије и видео снимци.",
    "Upload folder" : "Фолдер отпремања",
    "Choose the folder where photos and albums are uploaded to." : "Изаберите фолдер у који се отпремају фотографије и албуми.",
    "_%n photo_::_%n photos_" : ["%n фотографија","%n фотографије","%n фотографија"],
    "Unselect all" : "Поништи цео избор",
    "Add photos to this album" : "Додај фотографије у овај албум",
    "Manage collaborators for this album" : "Управљање сарадницима на овом албуму",
    "Open actions menu" : "Отвори мени са акцијама",
    "Edit album details" : "Уреди детаље о албуму",
    "Download all files in album" : "Преузми све фајлове у албуму",
    "Delete album" : "Обриши албум",
    "Download selected files" : "Преузми изабране фајлове",
    "Remove selection from album" : "Уклони избор са албума",
    "This album does not have any photos or videos yet!" : "Овај албум још увек нема ниједну фотографију или видео снимак!",
    "Add photos to {albumName}" : "Додај фотографије у {albumName}",
    "Manage collaborators" : "Управљај сарадницима",
    "Save collaborators for this album." : "Сачувај сараднике на овом албуму",
    "Cover photo for album {albumName}" : "Фотографија омота за албум {albumName}",
    "There is no album yet!" : "Још увек нема албума!",
    "This person could not be found" : "Ова особа не може да се пронађе",
    "Rename person" : "Промени име особе",
    "Merge with different person" : "Споји са другом особом",
    "Download selected photos" : "Преузми изабране фотографије",
    "Remove from favorites" : "Уклони из омиљених",
    "Remove person" : "Уклони особу",
    "Name of this person" : "Име ове особе",
    "Save." : "Сачувај.",
    "Merge person" : "Споји особу",
    "Move to different person" : "Премести другој особи",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Премести фотографију другој особи","Премести фотографије другој особи","Премести фотографије другој особи"],
    "_Remove photo from person_::_Remove photos from person_" : ["Уклони фотографију особи","Уклони фотографије особи","Уклони фотографије особи"],
    "This might take some time depending on the size of your photo library." : "У зависности од величине ваше фото библиотеке, ово може да потраје неко време.",
    "Recognized people will show up here" : "Овде ће се појавити препознате особе",
    "This folder does not exist" : "Овај фолдер не постоји",
    "Loading folders …" : "Учитавање фолдера ...",
    "No photos in here" : "Овде нема слика",
    "Taken on {date} at {time}" : "Сликано дана {date} у {time}",
    "This place does not have any photos or videos yet!" : "Ово место још увек нема ниједну фотографију или видео снимак!",
    "Add photos to this place" : "Додај фотографије на ово место",
    "Cover photo for place {placeName}" : "Фотографија омота за место {placeName}",
    "There is no place yet!" : "Још увек нема места!",
    "Cover photo for shared album {albumName}" : "Фотографија омота за дељени албум {albumName}",
    "Back to tags overview" : "Назад на преглед ознака",
    "No photos with this tag yet" : "Још увек нема фотографија са овом ознаком",
    "No tags yet" : "Још нема ознака",
    "Photos with tags will show up here" : "Слике са ознакама ће се појавити овде",
    "Popular tags" : "Популарне ознаке",
    "All tags" : "Све ознаке",
    "One of the source folders does not exist" : "Један од изворних фолдера не постоји",
    "Add to album" : "Додај у албум",
    "Delete selection" : "Обриши одабир",
    "No photos or videos in here" : "Овде нема фотографија или видео снимака",
    "Unassigned faces" : "Недодељена лица",
    "_%n photos_::_%n photos_" : ["%n фотографија","%n фотографије","%n фотографија"],
    "Failed to fetch collection." : "Није успело добављање колекције.",
    "Failed to fetch collections list." : "Није успело добављање листе колекција.",
    "Failed to fetch faces list." : "Није успело добављање листе лица.",
    "All your media" : "Сви ваши медији",
    "Album {title}" : "Албум {title}",
    "Shared Albums" : "Дељени албуми",
    "Shared album {title}" : "Дељени албум {title}",
    "Public album {title}" : "Јавни албум {title}",
    "Tagged photos" : "Слике са ознаком",
    "Tagged photo {title}" : "Означена фотографија {title}",
    "{title}'s face" : "лице {title}",
    "{startDate} to {endDate}" : "{startDate} до {endDate}",
    "Details" : "Детаљи",
    "Failed to rename {oldName} to {faceName}" : "Није успела промена имена {oldName} у {faceName}",
    "Failed to delete {faceName}" : "Није успело брисање {faceName}",
    "Failed to delete {fileId}" : "Није успело брисање {fileId}",
    "Failed to delete {fileName}" : "Није успело брисање {fileName}",
    "Failed to set favorite state for {fileId}" : "Није успело постављање стања омиљено за {fileId}",
    "Failed to set favorite state for {fileName}" : "Није успело постављање стања омиљено за {fileName}",
    "Could not load photos folder" : "Не може да се учита фолдер фотографија",
    "One of the source folders does not exists" : "Један од изворних фолдера не постоји",
    "Add" : "Додај"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
